==> wiki3_4_3.zip: wiki3_4_3/plugin/calendar/Calendar.pm <==
################################################################################
#
# <p>ɽޤ</p>
# <pre>
# {{calendar ̾}}
# </pre>
# <p>
# Ρ&lt;&lt;פ򥯥å
# &gt;&gt;פ򥯥å
# ǯ򥯥åȤηΥȥڡƤɽޤ
# ޤդ򥯥åȳդΥڡɽ
# ʥڡ¸ߤʤԽ̤ɽˤޤ
# </p>
# <p>
# ץ
# Խ̤˸ܤȤɽƥץ졼ȥڡꤹ뤳ȤǤޤ
# </p>
# <pre>
# {{calendar ̾[,ƥץ졼ȤȤʤڡ̾[,ɽ]]}}
# </pre>
# <p>
# ɽ<code>[Ⱦ10ʿ]next</code>Ƚ񤯤ȡ
# [Ⱦ10ʿ]Υɽޤ
# ɽ<code>[Ⱦ10ʿ]prev</code>Ƚ񤯤ȡ
# [Ⱦ10ʿ]Υɽޤ
# ɽ<code>[ȾѤ112]</code>Ƚ񤯤ȡ
# [112]Υɽޤ
# ¾ɽ̵뤵ޤ
# </p>
# <p>
# ʲ˥ץ饰λ򼨤ޤ
# </p>
# <pre>
# {{calendar ͽɽ}}
# {{calendar ͽɽ,ͽɽƥץ졼}}
# {{calendar ͽɽ,ͽɽƥץ졼,6}} : 6Υ
# {{calendar ͽɽ, ,1next}} : Υ
# {{calendar ͽɽ, ,2prev}} : 衹Υ
# </pre>
# <p>
# CSSɽѹ뤳ȤޤѤƤ륯饹̾ϰʲ̤Ǥ
# </p>
# <ul>
#   <li>today - </li>
#   <li>have - ͽΤ</li>
#   <li>navi - ʥӥС</li>
#   <li>week - </li>
#   <li>calendar - tableʬ</li>
#   <li>plugin-calendar - calendarץ饰ν</li>
# </ul>
# <p>
# ѤƤid̾ϰʲ̤Ǥ
# </p>
# <ul>
#   <li>calendar-[ȾѤ112] - [112]ꤵ줿</li>
#   <li>calendar-[Ⱦ10ʿ]next - [Ⱦ10ʿ]ꤷ</li>
#   <li>calendar-[Ⱦ10ʿ]prev - [Ⱦ10ʿ]ꤷ</li>
#   <li>calendar-sun - </li>
#   <li>weekday - ʿ</li>
#   <li>calendar-sat - </li>
# </ul>
#
################################################################################
package plugin::calendar::Calendar;
#use strict;
use plugin::calendar::CalendarHandler;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
    my $class = shift;
    my $self = {};
    return bless $self,$class;
}
#===============================================================================
# 饤᥽å
#===============================================================================
sub inline {
    my $self  = shift;
    my $wiki  = shift;
    my $name  = shift;
    my $template = shift;
    my $argmon = shift;
#	my $align = shift;
    
    my $error_message = "";

    # ¸ߤʤƥץ졼Ȥꤵ줿硣
    undef $template if !$wiki->page_exists($template);

#	# ɽֻ꤬ʤ硣
#	$align = "left" if $align eq "";


    # 顼å
    $error_message = "̾ꤵƤޤ" if($name eq "");
#    $error_message = "ɽꤵƤޤ" if($argmon eq "");
#    $error_message = "ְֻ꤬äƤޤ[$align]" if !(($align eq "center") || ($align eq "right") || ($align eq "left"));
    return Util::error($error_message) if !($error_message eq "");
    
    my ($sec, $min, $hour, $mday, $mon, $year, $wday) = localtime(time());
    $year += 1900;
    $mon  += 1;

    my $id = "";
    # ɽ
    if ($argmon =~ /(\d*)next/i) { # лʼ
	my $step = ($1 > 0) ? $1 : 1;
	$mon += $step;
	$id = "calendar-${step}next";
    } elsif ($argmon =~ /(\d*)prev/i) {	# л
	my $step = ($1 > 0) ? $1 : 1;
	$mon -= $step;
	$id = "calendar-${step}prev";
    } elsif ($argmon =~ /(\d+)/) { # л
	if ($1>=1 and $1<=12) {
	    $year += (($1 - $mon) >  6) ? -1 : 0;
	    $year += (($1 - $mon) < -6) ?  1 : 0;
	    $mon = $1;
	    $id = "calendar-$1";
	}
    } else {			# ʤ
    }
    # ǯ
    if ($mon > 0) {
	$year += int (($mon - 1) / 12);
    } else {
	$year += int (($mon - 12) / 12);
    }
    $mon = ($mon - 1) % 12 + 1;

    return &plugin::calendar::CalendarHandler::make_calendar($wiki,$year,$mon,$name,$template,$id);
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/calendar/Calendar.pm <==
################################################################################
#
# <p>ɽޤ</p>
# <pre>
# {{calendar ̾}}
# </pre>
# <p>
# Ρ&lt;&lt;פ򥯥å
# &gt;&gt;פ򥯥å
# ǯ򥯥åȤηΥȥڡƤɽޤ
# ޤդ򥯥åȳդΥڡɽ
# ʥڡ¸ߤʤԽ̤ɽˤޤ
# </p>
# <p>
# ץ
# Խ̤˸ܤȤɽƥץ졼ȥڡꤹ뤳ȤǤޤ
# </p>
# <pre>
# {{calendar ̾[,ƥץ졼ȤȤʤڡ̾[,ɽ]]}}
# </pre>
# <p>
# ɽ<code>[Ⱦ10ʿ]next</code>Ƚ񤯤ȡ
# [Ⱦ10ʿ]Υɽޤ
# ɽ<code>[Ⱦ10ʿ]prev</code>Ƚ񤯤ȡ
# [Ⱦ10ʿ]Υɽޤ
# ɽ<code>[ȾѤ112]</code>Ƚ񤯤ȡ
# [112]Υɽޤ
# ¾ɽ̵뤵ޤ
# </p>
# <p>
# ʲ˥ץ饰λ򼨤ޤ
# </p>
# <pre>
# {{calendar ͽɽ}}
# {{calendar ͽɽ,ͽɽƥץ졼}}
# {{calendar ͽɽ,ͽɽƥץ졼,6}} : 6Υ
# {{calendar ͽɽ, ,1next}} : Υ
# {{calendar ͽɽ, ,2prev}} : 衹Υ
# </pre>
# <p>
# CSSɽѹ뤳ȤޤѤƤ륯饹̾ϰʲ̤Ǥ
# </p>
# <ul>
#   <li>today - </li>
#   <li>have - ͽΤ</li>
#   <li>navi - ʥӥС</li>
#   <li>week - </li>
#   <li>calendar - tableʬ</li>
#   <li>plugin-calendar - calendarץ饰ν</li>
# </ul>
# <p>
# ѤƤid̾ϰʲ̤Ǥ
# </p>
# <ul>
#   <li>calendar-[ȾѤ112] - [112]ꤵ줿</li>
#   <li>calendar-[Ⱦ10ʿ]next - [Ⱦ10ʿ]ꤷ</li>
#   <li>calendar-[Ⱦ10ʿ]prev - [Ⱦ10ʿ]ꤷ</li>
#   <li>calendar-sun - </li>
#   <li>weekday - ʿ</li>
#   <li>calendar-sat - </li>
# </ul>
#
################################################################################
package plugin::calendar::Calendar;
#use strict;
use plugin::calendar::CalendarHandler;
#===============================================================================
# 󥹥ȥ饯
#===============================================================================
sub new {
    my $class = shift;
    my $self = {};
    return bless $self,$class;
}

#===============================================================================
# ѥ饰
#===============================================================================
sub paragraph {
    my $self  = shift;
    my $wiki  = shift;
    my $name  = shift;
    my $template = shift;
    my $argmon = shift;
#	my $align = shift;
    
    my $error_message = "";

    # ¸ߤʤƥץ졼Ȥꤵ줿硣
    undef $template if !$wiki->page_exists($template);

#	# ɽֻ꤬ʤ硣
#	$align = "left" if $align eq "";


    # 顼å
    $error_message = "̾ꤵƤޤ" if($name eq "");
#    $error_message = "ɽꤵƤޤ" if($argmon eq "");
#    $error_message = "ְֻ꤬äƤޤ[$align]" if !(($align eq "center") || ($align eq "right") || ($align eq "left"));
    return Util::paragraph_error($error_message) if !($error_message eq "");
    
    my ($sec, $min, $hour, $mday, $mon, $year, $wday) = localtime(time());
    $year += 1900;
    $mon  += 1;

    my $id = "";
    # ɽ
    if ($argmon =~ /(\d*)next/i) { # лʼ
	my $step = ($1 > 0) ? $1 : 1;
	$mon += $step;
	$id = "calendar-${step}next";
    } elsif ($argmon =~ /(\d*)prev/i) {	# л
	my $step = ($1 > 0) ? $1 : 1;
	$mon -= $step;
	$id = "calendar-${step}prev";
    } elsif ($argmon =~ /(\d+)/) { # л
	if ($1>=1 and $1<=12) {
	    $year += (($1 - $mon) >  6) ? -1 : 0;
	    $year += (($1 - $mon) < -6) ?  1 : 0;
	    $mon = $1;
	    $id = "calendar-$1";
	}
    } else {			# ʤ
    }
    # ǯ
    if ($mon > 0) {
	$year += int (($mon - 1) / 12);
    } else {
	$year += int (($mon - 12) / 12);
    }
    $mon = ($mon - 1) % 12 + 1;

    return &plugin::calendar::CalendarHandler::make_calendar($wiki,$year,$mon,$name,$template,$id);
}

1;
